==> vue3-components-0.2.28.tgz: package/es/notification/src/notification.vue2.js <==
import { defineComponent as w, resolveComponent as c, openBlock as t, createBlock as s, withCtx as l, createVNode as i, renderSlot as u, resolveDynamicComponent as h, createElementBlock as n, Fragment as p, renderList as k, createCommentVNode as a, createElementVNode as g, toDisplayString as _, createTextVNode as E } from "vue";
import { notificationProps as S } from "./notification.js";
const T = ["onClick"], z = {
  key: 0,
  class: "avatar"
}, F = { class: "content" }, K = {
  key: 0,
  class: "title"
}, L = { key: 0 }, P = { key: 1 }, j = {
  key: 2,
  class: "desc"
}, q = { class: "actions" }, x = ["onClick"], G = {
  key: 1,
  class: "item2"
}, H = {
  name: "KNotification"
}, Q = /* @__PURE__ */ w({
  ...H,
  props: S,
  emits: ["clickItem", "clickAction"],
  setup(J, { emit: m }) {
    const y = ({ item: o, index: d }) => {
      m("clickItem", { item: o, index: d });
    }, b = ({ item: o, index: d }) => {
      m("clickAction", { item: o, index: d });
    };
    return (o, d) => {
      const C = c("el-avatar"), N = c("el-tag"), $ = c("el-scrollbar"), v = c("el-icon"), V = c("el-tab-pane"), A = c("el-tabs"), B = c("el-badge"), D = c("el-popover");
      return t(), s(D, {
        placement: "bottom",
        width: 300,
        trigger: "click"
      }, {
        reference: l(() => [
          i(B, {
            value: o.value,
            max: o.max,
            "is-dot": o.isDot
          }, {
            default: l(() => [
              i(v, null, {
                default: l(() => [
                  u(o.$slots, "icon", {}, () => [
                    (t(), s(h(o.icon)))
                  ], !0)
                ]),
                _: 3
              })
            ]),
            _: 3
          }, 8, ["value", "max", "is-dot"])
        ]),
        default: l(() => [
          i(A, null, {
            default: l(() => [
              (t(!0), n(p, null, k(o.list, (f) => (t(), s(V, {
                label: f.title
              }, {
                default: l(() => [
                  i($, { "max-height": "300px" }, {
                    default: l(() => [
                      (t(!0), n(p, null, k(f.content, (e, r) => (t(), n("div", {
                        class: "container",
                        onClick: (I) => y({ item: e, index: r })
                      }, [
                        u(o.$slots, "default", {
                          item: e,
                          index: r
                        }, () => [
                          e.avatar ? (t(), n("div", z, [
                            i(C, {
                              src: e.avatar
                            }, null, 8, ["src"])
                          ])) : a("", !0),
                          g("div", F, [
                            e.title || e.tag ? (t(), n("p", K, [
                              e.title ? (t(), n("span", L, _(e.title), 1)) : a("", !0),
                              e.tag ? (t(), s(N, {
                                key: 1,
                                type: e.tagType,
                                size: "small"
                              }, {
                                default: l(() => [
                                  E(_(e.tag), 1)
                                ]),
                                _: 2
                              }, 1032, ["type"])) : a("", !0)
                            ])) : a("", !0),
                            e.time ? (t(), n("time", P, _(e.time), 1)) : a("", !0),
                            e.desc ? (t(), n("p", j, _(e.desc), 1)) : a("", !0)
                          ])
                        ], !0)
                      ], 8, T))), 256))
                    ]),
                    _: 2
                  }, 1024),
                  g("div", q, [
                    (t(!0), n(p, null, k(o.actions, (e, r) => (t(), n("div", {
                      onClick: (I) => b({ item: e, index: r })
                    }, [
                      u(o.$slots, "action", {
                        item: e,
                        index: r
                      }, () => [
                        e.icon ? (t(), s(v, { key: 0 }, {
                          default: l(() => [
                            (t(), s(h(e.icon)))
                          ]),
                          _: 2
                        }, 1024)) : a("", !0),
                        e.text ? (t(), n("div", G, _(e.text), 1)) : a("", !0)
                      ], !0)
                    ], 8, x))), 256))
                  ])
                ]),
                _: 2
              }, 1032, ["label"]))), 256))
            ]),
            _: 3
          })
        ]),
        _: 3
      });
    };
  }
});
export {
  Q as default
};

==> vue3-components-0.2.32.tgz: package/es/notification/src/notification.vue2.js <==
import { defineComponent as y, resolveComponent as c, openBlock as t, createBlock as s, withCtx as l, createVNode as i, renderSlot as u, resolveDynamicComponent as h, createElementBlock as n, Fragment as p, renderList as k, createCommentVNode as a, createElementVNode as g, toDisplayString as _, createTextVNode as E } from "vue";
import { notificationProps as S } from "./notification.js";
const T = ["onClick"], z = {
  key: 0,
  class: "avatar"
}, F = { class: "content" }, K = {
  key: 0,
  class: "title"
}, L = { key: 0 }, P = { key: 1 }, j = {
  key: 2,
  class: "desc"
}, q = { class: "actions" }, x = ["onClick"], G = {
  key: 1,
  class: "item2"
}, H = y({
  name: "KNotification"
}), Q = /* @__PURE__ */ y({
  ...H,
  props: S,
  emits: ["clickItem", "clickAction"],
  setup(J, { emit: m }) {
    const b = ({ item: o, index: d }) => {
      m("clickItem", { item: o, index: d });
    }, C = ({ item: o, index: d }) => {
      m("clickAction", { item: o, index: d });
    };
    return (o, d) => {
      const N = c("el-avatar"), $ = c("el-tag"), V = c("el-scrollbar"), v = c("el-icon"), A = c("el-tab-pane"), B = c("el-tabs"), D = c("el-badge"), I = c("el-popover");
      return t(), s(I, {
        placement: "bottom",
        width: 300,
        trigger: "click"
      }, {
        reference: l(() => [
          i(D, {
            value: o.value,
            max: o.max,
            "is-dot": o.isDot
          }, {
            default: l(() => [
              i(v, null, {
                default: l(() => [
                  u(o.$slots, "icon", {}, () => [
                    (t(), s(h(o.icon)))
                  ], !0)
                ]),
                _: 3
              })
            ]),
            _: 3
          }, 8, ["value", "max", "is-dot"])
        ]),
        default: l(() => [
          i(B, null, {
            default: l(() => [
              (t(!0), n(p, null, k(o.list, (f) => (t(), s(A, {
                label: f.title
              }, {
                default: l(() => [
                  i(V, { "max-height": "300px" }, {
                    default: l(() => [
                      (t(!0), n(p, null, k(f.content, (e, r) => (t(), n("div", {
                        class: "container",
                        onClick: (w) => b({ item: e, index: r })
                      }, [
                        u(o.$slots, "default", {
                          item: e,
                          index: r
                        }, () => [
                          e.avatar ? (t(), n("div", z, [
                            i(N, {
                              src: e.avatar
                            }, null, 8, ["src"])
                          ])) : a("", !0),
                          g("div", F, [
                            e.title || e.tag ? (t(), n("p", K, [
                              e.title ? (t(), n("span", L, _(e.title), 1)) : a("", !0),
                              e.tag ? (t(), s($, {
                                key: 1,
                                type: e.tagType,
                                size: "small"
                              }, {
                                default: l(() => [
                                  E(_(e.tag), 1)
                                ]),
                                _: 2
                              }, 1032, ["type"])) : a("", !0)
                            ])) : a("", !0),
                            e.time ? (t(), n("time", P, _(e.time), 1)) : a("", !0),
                            e.desc ? (t(), n("p", j, _(e.desc), 1)) : a("", !0)
                          ])
                        ], !0)
                      ], 8, T))), 256))
                    ]),
                    _: 2
                  }, 1024),
                  g("div", q, [
                    (t(!0), n(p, null, k(o.actions, (e, r) => (t(), n("div", {
                      onClick: (w) => C({ item: e, index: r })
                    }, [
                      u(o.$slots, "action", {
                        item: e,
                        index: r
                      }, () => [
                        e.icon ? (t(), s(v, { key: 0 }, {
                          default: l(() => [
                            (t(), s(h(e.icon)))
                          ]),
                          _: 2
                        }, 1024)) : a("", !0),
                        e.text ? (t(), n("div", G, _(e.text), 1)) : a("", !0)
                      ], !0)
                    ], 8, x))), 256))
                  ])
                ]),
                _: 2
              }, 1032, ["label"]))), 256))
            ]),
            _: 3
          })
        ]),
        _: 3
      });
    };
  }
});
export {
  Q as default
};
